@@ -56,7 +56,7 @@ TQt::AlignmentFlags CrystalFactory::titlealign_ = TQt::AlignHCenter;
 
 extern "C"
 {
-	KDE_EXPORT KDecorationFactory* create_factory()
+	TDE_EXPORT KDecorationFactory* create_factory()
 	{
 		return new CrystalFactory();
 	}
