@@ -84,8 +84,8 @@ void QImageHolder::Init()
 	rootpixmap=new KMyRootPixmap(NULL/*,this*/);
 	rootpixmap->start();
 	rootpixmap->repaint(true);
-	connect( rootpixmap,TQT_SIGNAL(backgroundUpdated(const TQImage*)),this, TQT_SLOT(BackgroundUpdated(const TQImage*)));
-	connect(kapp, TQT_SIGNAL(backgroundChanged(int)),TQT_SLOT(handleDesktopChanged(int)));
+	connect( rootpixmap,TQ_SIGNAL(backgroundUpdated(const TQImage*)),this, TQ_SLOT(BackgroundUpdated(const TQImage*)));
+	connect(kapp, TQ_SIGNAL(backgroundChanged(int)),TQ_SLOT(handleDesktopChanged(int)));
 	
 	initialized=true;
 }
